var namespaceopenvdb_1_1v12__1_1_1io =
[
    [ "Archive", "classopenvdb_1_1v12__1_1_1io_1_1Archive.html", "classopenvdb_1_1v12__1_1_1io_1_1Archive" ],
    [ "MaskCompress", "structopenvdb_1_1v12__1_1_1io_1_1MaskCompress.html", "structopenvdb_1_1v12__1_1_1io_1_1MaskCompress" ],
    [ "RealToHalf", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf" ],
    [ "RealToHalf&lt; float &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01float_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01float_01_4" ],
    [ "RealToHalf&lt; double &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01double_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01double_01_4" ],
    [ "RealToHalf&lt; Vec2s &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2s_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2s_01_4" ],
    [ "RealToHalf&lt; Vec2d &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2d_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec2d_01_4" ],
    [ "RealToHalf&lt; Vec3s &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3s_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3s_01_4" ],
    [ "RealToHalf&lt; Vec3d &gt;", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3d_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1RealToHalf_3_01Vec3d_01_4" ],
    [ "HalfReader", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader.html", null ],
    [ "HalfReader&lt; false, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01false_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01false_00_01T_01_4" ],
    [ "HalfReader&lt; true, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01true_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfReader_3_01true_00_01T_01_4" ],
    [ "HalfWriter", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter.html", null ],
    [ "HalfWriter&lt; false, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01false_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01false_00_01T_01_4" ],
    [ "HalfWriter&lt; true, T &gt;", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01true_00_01T_01_4.html", "structopenvdb_1_1v12__1_1_1io_1_1HalfWriter_3_01true_00_01T_01_4" ],
    [ "DelayedLoadMetadata", "classopenvdb_1_1v12__1_1_1io_1_1DelayedLoadMetadata.html", "classopenvdb_1_1v12__1_1_1io_1_1DelayedLoadMetadata" ],
    [ "File", "classopenvdb_1_1v12__1_1_1io_1_1File.html", "classopenvdb_1_1v12__1_1_1io_1_1File" ],
    [ "GridDescriptor", "classopenvdb_1_1v12__1_1_1io_1_1GridDescriptor.html", "classopenvdb_1_1v12__1_1_1io_1_1GridDescriptor" ],
    [ "StreamMetadata", "classopenvdb_1_1v12__1_1_1io_1_1StreamMetadata.html", "classopenvdb_1_1v12__1_1_1io_1_1StreamMetadata" ],
    [ "MultiPass", "structopenvdb_1_1v12__1_1_1io_1_1MultiPass.html", null ],
    [ "Queue", "classopenvdb_1_1v12__1_1_1io_1_1Queue.html", "classopenvdb_1_1v12__1_1_1io_1_1Queue" ],
    [ "Stream", "classopenvdb_1_1v12__1_1_1io_1_1Stream.html", "classopenvdb_1_1v12__1_1_1io_1_1Stream" ],
    [ "bloscFromStream", "namespaceopenvdb_1_1v12__1_1_1io.html#adfd249ead2665218332388cc9300f4ea", null ],
    [ "bloscToStream", "namespaceopenvdb_1_1v12__1_1_1io.html#a991bbbdbdb7796b490bb386dd914b2bd", null ],
    [ "bloscToStreamSize", "namespaceopenvdb_1_1v12__1_1_1io.html#a86c986c431d1f36ad85d55b306898013", null ],
    [ "clearStreamMetadataPtr", "namespaceopenvdb_1_1v12__1_1_1io.html#aa809c9596b637539e3926ac026d3edfa", null ],
    [ "compressionToString", "namespaceopenvdb_1_1v12__1_1_1io.html#aa27287275526fbc0b2d4b3a54d5a5f31", null ],
    [ "getDataCompression", "namespaceopenvdb_1_1v12__1_1_1io.html#a02c214bb9fd4d3099ab16424e006689d", null ],
    [ "getErrorString", "namespaceopenvdb_1_1v12__1_1_1io.html#a1ea104b09e8346cbae0f360858d76220", null ],
    [ "getErrorString", "namespaceopenvdb_1_1v12__1_1_1io.html#a60c1539e1517e078f7c5ebf7c669f0d5", null ],
    [ "getFormatVersion", "namespaceopenvdb_1_1v12__1_1_1io.html#a323db79e63bafb11c4343d041bde05b8", null ],
    [ "getGridBackgroundValuePtr", "namespaceopenvdb_1_1v12__1_1_1io.html#a9d3b9d15e51cc1e37aede1f602293388", null ],
    [ "getGridClass", "namespaceopenvdb_1_1v12__1_1_1io.html#aca9403703e72565a612f54b0fa5207c6", null ],
    [ "getHalfFloat", "namespaceopenvdb_1_1v12__1_1_1io.html#a78a23328593a57bc09bd5769092eddac", null ],
    [ "getLibraryVersion", "namespaceopenvdb_1_1v12__1_1_1io.html#a4514a103d6dbe511f84a780c388e5d1e", null ],
    [ "getStreamMetadataPtr", "namespaceopenvdb_1_1v12__1_1_1io.html#ad2f279ebe14f8fce542c785624a2db85", null ],
    [ "getVersion", "namespaceopenvdb_1_1v12__1_1_1io.html#ae4d6c3d95a5af56878e7a943a5e36f0b", null ],
    [ "getWriteGridStatsMetadata", "namespaceopenvdb_1_1v12__1_1_1io.html#a81e30a665391cdf74e679989a2f2583c", null ],
    [ "operator<<", "namespaceopenvdb_1_1v12__1_1_1io.html#a7d55ab46b0171a80bed8b8e9f306e141", null ],
    [ "operator<<", "namespaceopenvdb_1_1v12__1_1_1io.html#aa6a1680f0c1d9f83de430c79c5579eed", null ],
    [ "readCompressedValues", "namespaceopenvdb_1_1v12__1_1_1io.html#a83e05f7cf1753bc1012789b7903a4dee", null ],
    [ "readCompressedValues", "namespaceopenvdb_1_1v12__1_1_1io.html#a9b731e1ddad7938c2f6235df52d95f20", null ],
    [ "readData", "namespaceopenvdb_1_1v12__1_1_1io.html#aeafecea17aad3f9d7d80d05d0c22f523", null ],
    [ "readData< std::string >", "namespaceopenvdb_1_1v12__1_1_1io.html#a2e062642c2571f53f117850f21e771f9", null ],
    [ "setCurrentVersion", "namespaceopenvdb_1_1v12__1_1_1io.html#a2e471b075c915bd2303ffc48cd132a7b", null ],
    [ "setDataCompression", "namespaceopenvdb_1_1v12__1_1_1io.html#afbaf507bb288e4b75e3102eca14404c4", null ],
    [ "setGridBackgroundValuePtr", "namespaceopenvdb_1_1v12__1_1_1io.html#a2df1d378247ff2c322fb3ddad9b8a245", null ],
    [ "setGridClass", "namespaceopenvdb_1_1v12__1_1_1io.html#adf56f19f911dd30fd3e8c003269dab21", null ],
    [ "setHalfFloat", "namespaceopenvdb_1_1v12__1_1_1io.html#adeb33d6c7e42e7245d130493c241addd", null ],
    [ "setStreamMetadataPtr", "namespaceopenvdb_1_1v12__1_1_1io.html#ab54abce5c70771a57711e2bfcfb3e457", null ],
    [ "setVersion", "namespaceopenvdb_1_1v12__1_1_1io.html#a98908fc95cdbb9b9f2845c1e0495ee69", null ],
    [ "setWriteGridStatsMetadata", "namespaceopenvdb_1_1v12__1_1_1io.html#a8a5740735895767229359ab76e452cfd", null ],
    [ "truncateRealToHalf", "namespaceopenvdb_1_1v12__1_1_1io.html#a4c519c3dc6d997f5bdf94d451e97bb2d", null ],
    [ "unzipFromStream", "namespaceopenvdb_1_1v12__1_1_1io.html#a7da1a0ef643aec0d3f345bb93813b427", null ],
    [ "writeCompressedValues", "namespaceopenvdb_1_1v12__1_1_1io.html#ac6b1aefe7ee347cbd1b61f40b3f333c3", null ],
    [ "writeCompressedValues", "namespaceopenvdb_1_1v12__1_1_1io.html#a1645f9ec1e95a97e594b33cbbd7288d8", null ],
    [ "writeCompressedValuesSize", "namespaceopenvdb_1_1v12__1_1_1io.html#add4d7f52fea9a901e65f1d95667b87d8", null ],
    [ "writeCompressedValuesSize", "namespaceopenvdb_1_1v12__1_1_1io.html#af035569c761c1c8ad18078b667c8e3e4", null ],
    [ "writeData", "namespaceopenvdb_1_1v12__1_1_1io.html#a9b958591f15ed772898f6135e5fd2446", null ],
    [ "writeData< std::string >", "namespaceopenvdb_1_1v12__1_1_1io.html#ac4550daecdfddacb7ffb0f65c95bf1cf", null ],
    [ "writeDataSize", "namespaceopenvdb_1_1v12__1_1_1io.html#afdfd01a8cf96cd9dc0a6cb74d2d75655", null ],
    [ "writeDataSize< std::string >", "namespaceopenvdb_1_1v12__1_1_1io.html#af1b4dabd1b519fbb503a4acef3266993", null ],
    [ "zipToStream", "namespaceopenvdb_1_1v12__1_1_1io.html#a326dc4ab84b17fd824b83711a359c934", null ],
    [ "zipToStreamSize", "namespaceopenvdb_1_1v12__1_1_1io.html#a0650b3bc51a2928e265d40133905caf9", null ]
];